The batting averages of 18 Major League Baseball players through their first 45
at-bats of the 1970 season, along with their batting average for the remainder
the season.

The data has been modified from the table in the paper, as used for case studies
using Stan and PyMC3, by adding columns explicitly listing the number of at-bats
early in the season, as well as at-bats and hits for the full season.
